@@ -12,6 +12,7 @@ from email.mime.application import MIMEApplication
 import logging
 from email.mime.text import MIMEText
 import smtplib
+
 warnings.filterwarnings("ignore")  # 忽略警告
 
 
@@ -81,7 +82,6 @@ class ezfuc(object):
             res = res.decode("utf-8")
             return DefaultMunch.fromDict(res, default)
 
-
     @staticmethod
     def object_to_dict(res, ex="dict"):
         """
@@ -191,6 +191,15 @@ class ezfuc(object):
 
         return deco
 
+    @staticmethod
+    def get_time():
+        """
+    	获取当前时间
+    	"""
+        import time
+        now_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+        return str(now_time)
+
     @staticmethod
     def sleep(t):
         """
@@ -268,15 +277,6 @@ class ezfuc(object):
         else:
             return False
 
-    @staticmethod
-    def get_time():
-    	"""
-    	获取当前时间
-    	"""
-    	import time
-	    now_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-	    return str(now_time)
-
     @staticmethod
     def random_ua():
         """
@@ -482,7 +482,7 @@ class EmailSend(object):
             # print('连接邮箱服务器异常：',e)
             self.logging.error('连接邮箱服务器异常：{}'.format(e))
 
-    def send_xlsx_email(self, to_address,  from_addr='email', subject='title', file_name=""):
+    def send_xlsx_email(self, to_address, from_addr='email', subject='title', file_name=""):
         msg = MIMEMultipart()
         msg['From'] = formataddr(["筑龙爬虫部", from_addr])
         msg['To'] = to_address
@@ -503,8 +503,6 @@ class EmailSend(object):
         except Exception as e:
             self.logging.error('连接邮箱服务器异常：{}'.format(e))
 
-
-
     def send_word_email(self):
         pass
 
@@ -515,13 +513,13 @@ class EmailSend(object):
 @ezfuc.retry(2)
 def getIP():
     try:
-        res = requests.get("http://192.168.18.47:39111/123",timeout=3).json()
+        res = requests.get("http://192.168.18.47:39111/123", timeout=3).json()
     except:
         return None
 
-    if res["code"] ==200:
+    if res["code"] == 200:
         return res
-    elif res["code"] ==300:
+    elif res["code"] == 300:
         ezfuc.color_print("添加白名单失败", color="yellow")
         ezfuc.sleep(2)
         getIP()
@@ -545,5 +543,6 @@ def ezproxy(req):
         req.meta["proxy"] = res["proxy"]
         req.headers["Proxy-Authorization"] = proxyAuth
         return req
-    except:
-        return req
\ No newline at end of file
+    except Exception as e:
+        ezfuc.color_print(e)
+        return req
