@@ -38,8 +38,10 @@ class SqlServerOdbc(object):
         if "%s" in sqlStr:
             sqlStr = sqlStr.replace("%s", "?")
         rows = self.get(sqlStr, *args)
-        columns = [column[0] for column in self.cursor.description]
-        return dict(zip(columns, rows))
+        if rows:
+            columns = [column[0] for column in self.cursor.description]
+            return dict(zip(columns, rows))
+        return dict()
 
     def query(self, sqlStr, *args, max_count=None):
         """
